<?php
/***************************************************************
	fgw_ajax_proc.php
	FAMILY GROUP WORKSHEET AJAX EMAILER

	v43 Removes certain restrictions from admins.
	Permits admin to save empty worksheet.
	Does not prefill worksheet with admin's personal data.
	If submitter's name and email are missing, no email is sent.
***************************************************************/
# Essential for proper rendering of special chars in supported languages

// PROTECT SCRIPT AGAINST DIRECT ACCESS
if( empty( $_POST ) || !is_array( $_POST ) ) {
	@session_start();
	$_SESSION['fgw_alert'] = 3;
	header( 'Location:fgw_alert.php' );
	exit;
}
@session_start();
$thecharset = $_SESSION['session_charset'];
header("Content-Type:text/html; charset=$thecharset");
ini_set( 'default_charset', $thecharset );

require 'fgw_lib.php';
require 'fgw_logger.php';
require '../tngmaillib.php';

$options = fgw_sanitize_recursive( $options );
foreach( $options as $key => $value ) {
    ${$key} = $value;
}
//$fgw_logstring = $text['ws_submitted'];

/***************************************************************
SAVE POSTED DATA TO DATABASE WORKSHEET
***************************************************************/
if( !isset( $_POST ) || !is_array($_POST) ) exit;

// extract the posted form data
foreach ($_POST as $key => $value) {
  $post[$key] = ${$key} = fgw_sanitize_recursive( $value );
}
// spam checks
if( !empty( $comment ) ) { // spambot fell for the honeypot
  fgw_writelog($options['userlog'], "Error " . __LINE__ . ": spambot trap", $options['max_loglines'] );
  header("Location: fgw.php");
  exit;
}

// verify captcha
if( !empty( $options['show_captcha'] ) ) {
   $newhash = md5( strtolower($capcode));
   if( $newhash != $fgw_hash ) {
   	echo "Please enter correct security code!";
      exit;
   }
}
// don's save these values to the database
$post['capcode'] = '';
$post['fgw_hash'] = '';

// ADMIN NEED NOT PROVIDE THIS: IF MISSING NO EMAIL IS SENT -- modified for v43
if( empty( $_SESSION['fgw_superuser'] ) ) {
	if( empty( $user['realname'] ) || empty( $user['email'] ) ) {
		echo "{$text['ws_need_email']}";
	  exit;
	}
}

$_SESSION['fgw_user'] = $user;

// ADMIN CAN SAVE EMPTY WORKSHEET IF HE WISHES -- added for v43
if( empty( $_SESSION['fgw_superuser'] ) ) {
	// either husband or wife must contain both first and last name
	if( empty( $husb['firstname'] ) || empty( $husb['lastname'] ) ) {
	  if( empty( $wife['firstname'] ) || empty( $wife['lastname'] ) ) {
	    echo $text['ws_noinfo'];
	    exit;
	  }
	}
}
$formTitle = fgw_title( $husb, $wife );
# all okay to this point -- save the form data

$familyID = empty( $_POST['marr']['familyID'] ) ? '' : $_POST['marr']['familyID'];

// remove empty child lines
$kids = array();
foreach( $post['child'] as $kid ) {
   if( !empty( $kid['firstname'] ) ) {
      $kids[] = $kid;
   }
}
$post['child'] = $kids;


//add famc to new kids
// foreach( $post['child'] if no personID famc = marr['familyID']
for( $i=0; isset($post['child'][$i]); $i++ ) {
   if( empty( $post['child'][$i]['famc'] ) ) {
      $post['child'][$i]['famc'] = $post['marr']['familyID'];
   }
}

$serialized = base64_encode( serialize( $post ) );
$serialized = db_escape( $serialized );

$formID = $post['formID'];

// UPDATE EXISTING DATABASE WORKSHEET
if( !empty( $formID ) ) {
   $query = "UPDATE {$options['table']}
	set data='$serialized', email='{$user['email']}',
	subname='{$user['realname']}', description='$formTitle',
	familyID='{$marr['familyID']}', husbID='{$husb['personID']}',
	wifeID='{$wife['personID']}', merged=0
	WHERE formID=$formID";
	db_update( $query );
	$logstring = "fgw#$formID {$text['ws_updatedby']}";
	fgw_writelog( $options['userlog'], $logstring, $options['max_loglines'] );
}

// SAVE NEW WORKSHEET TO DATABASE
else {
  // set date & time the worksheet is created
  $created = date( "Y-m-d H:m:s");

  // create a unique form key from the date/time
  $fkey = md5( $created );

  // ADD THE WORKSHEET
  $query = "INSERT INTO {$options['table']}
   (gedcom,description,data,email,subname,created,fkey,familyID, husbID, wifeID)
      VALUES
   ( '$gedcom', '$formTitle', '$serialized', '{$user['email']}','{$user['realname']}',
   '$created','$fkey','$familyID', '{$husb['personID']}', '{$wife['personID']}')";

  $formID = db_insert( $query );

  $logstring = "fgw#$formID {$text['ws_savedby']}";
  fgw_writelog( $options['userlog'], $logstring, $options['max_loglines'] );

}

// RESET THE MERGED FLAG
$query = "UPDATE {$options['table']} set merged=0
  WHERE formID=$formID";
db_update( $query );

// SET USER NAME IF LOGGED IN
$user['username'] = empty( $_SESSION['currentuser'] )
  ? 'not logged in'
  : $_SESSION['currentuser'];

// RETRIEVE WORKSHEET AND FKEY FROM DATABASE TO VERIFY THEM AND INCLUDE FKEY IN EMAILS
$form = fgw_fetch_form_record( $formID );
$fkey = $form['fkey'];

// added in ver 43 check for name and email -- email if present
if( !empty( $_SESSION['fgw_superuser'] ) ) {
		echo " FormID=$formID\nAdmin: {$text['ws_saved']}";
	   exit;

}

// each form-save generates message to admin once per session
/*
	EACH FORM-SAVE GENERATES MESSAGE TO ADMIN/SUBMITTER ONCE PER SESSION

	The purpose here is to record the posting of a worksheet as element of session array.
	When a worksheet is posted, script checks the session array to see if it has been
	previously posed in this session and if so, bypass the email to the admin.

	If not previously posted, add the $formID to the session array.
*/
if( !empty( $_SESSION['fgw_mailed'] ) ) {
   $fgw_mailed = $_SESSION['fgw_mailed'];
   foreach( $fgw_mailed as $mailed ) {
      if( $mailed == $formID ) {
        echo $text['ws_saved'];
        exit;
      }
   }
}

// SAVE THE NEW WORKSHEET ID TO A SESSION ARRAY AND CONTINUE WITH EMAIL
$_SESSION['fgw_mailed'][] = $formID;

/*************************************************************************
CONSTRUCT EMAIL MESSAGE BODY
*************************************************************************/
# credit string $user['credit'] formed in fgw.php?
$credit_string = empty( $user['realname'] ) ? "" : $user['realname'];
$credit_string.= empty($user['city'] ) ? "" : empty( $credit_string ) ? $user['city'] : ", {$user['city']}";
$credit_string.= empty($user['state'] ) ? "" : empty( $credit_string ) ? $user['state'] : ", {$user['state']}";
$credit_string.= empty($user['country'] ) ? "" : empty( $credit_string ) ? $user['country'] : ", {$user['country']}";

# if no trailing slash in website URL as configured, append one
$tngdomain = ( mb_substr( $tngdomain, -1, 1, $_SESSION['session_charset'] ) != '/' ) ?
$tngdomain .'/' :
$tngdomain;

# Start building message -- Title Section
$message = $formTitle . "\n";
$message.= "{$text['ws_submitted_to']}: $sitename ($tngdomain)\n";
$message.= empty( $credit_string ) ? "" : "{$text['ws_author']}: $credit_string ({$user['email']})\n";
$message.= empty( $urelation ) ? "" : $urelation."\n";
# Login Section
$message.= "\n";
$message.= strtoupper( $text['ws_login'] ) . "\n";
$message.="{$text['ws_user']}: ";
$message.=$user['username'] ? $user['username']."\n" : "not logged in\n";
$message.=$user['realname'] ? $text['ws_name'].': '.$user['realname']."\n" : "";
$message.=$user['email'] ? $text['ws_email'].': '.$user['email']."\n" : "";

$message .= "\n{$text['ws_familytree']}: ";
$message .= fgw_fetch_treename( $gedcom );
$message .= "\n\n";
$message .= $text['ws_link'].":\n";

// INSERT LINK BACK TO STORED WORKSHEET
$murl = "http" . ((!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on' ) ? "s://" : "://" ) . $_SERVER['HTTP_HOST'] . $_SERVER['PHP_SELF'];

$murl = str_replace( 'fgw_ajax_proc.php', 'fgw.php', $murl );

$message .= "$murl?id=$formID&fkey=$fkey";
// need to change above to reflect fgw.php at root


//echo __LINE__,' ',$message;exit;
$message.="\n\n";

/*************************************************************************
SEND THE EMAIL MESSAGE SEPARATELY TO THE ADMIN AND THEN TO THE SUBMITTER
*************************************************************************/
$message .= $text['ws_thanks'];

// SET ADMIN ADDRESS TO USE -- ALTERNATE DEFINED IN SETUP.PHP AND STORED IN USER_CONFIG.PHP
$adminmailtouse = $alt_addr ? $alt_addr : $emailaddr;
$adminnametouse = $alt_name ? $alt_name : ($sitename ? $sitename : $dbowner);


if( !empty( $familyID ) ) 
	$persfam = '('.$familyID.')';
elseif( !empty( $husb['personID'] ) )
	$persfam =  '('.$husb['personID'].')';
elseif( !empty( $wife['personID'] ) )
	$persfam =  '('.$wife['personID'].')';
else
	$persfam = null;

# send message to site administrator
$sent = tng_sendmail($user['realname'], $user['email'], $adminnametouse, $adminmailtouse, $text['ws_fgw']." $persfam", $message, $user['email'], $user['email']);

# if all is well, send a copy back to the contributor
if ( $sent )
    $sent = tng_sendmail($adminnametouse, $adminmailtouse, $user['realname'], $user['email'], $text['ws_fgw']." $persfam", $message, $adminmailtouse, $adminmailtouse);

# compose on-screen status message
if ($sent) {
    if( !empty( $_SESSION['fgw_newform'] ) ) {
        //refresh screen after after first submission
        unset( $_SESSION['fgw_newform'] );
        echo $formID,'|',$fkey,'|',$text['ws_thanks'];
    }
    else {
        //just show message - don't refresh screen since nothing changes on it
        echo $text['ws_thanks'];
    }
}
else
  echo $text['ws_notsent']; exit;
?>