<?php
/*
	fgw_lib.php
	Family Group Workseet library functions
*/

//PREVENT DIRECT ACCESS TO THIS SCRIPT
if( count(get_included_files()) == 1 ) {
	@session_start();
	$_SESSION['fgw_alert'] = 3;
	header( 'Location:fgw_alert.php' );
	exit;
}

include 'fgw_language.php';
include 'fgw_db.php';
define( 'LIV_PERUSER',  0 );
define( 'LIV_NEVER',    1 );
define( 'LIV_ALWAYS',   2 );
define( 'USERLOG', 'userlog.php' );

/*************************************************************************
ADMINISTRATIVE
*************************************************************************/
function fgw_password() {
  $password = "";
  $length = 8;
  $allowed = "0123456789bcdfghjkmnpqrstvwxyz";

  $i = 0;
  while( $i < $length ) {
    $char = substr( $allowed, mt_rand( 0, strlen( $allowed ) - 1 ), 1 );
    if( !strstr( $password, $char ) ) {
      $password .= $char;
      $i++;
    }
  }
  return $password;
}

function fgw_curr_page_url() {
  $pageURL = 'http';
  if( isset( $_SERVER["HTTPS"] ) ) {$pageURL .= "s";}
  $pageURL .= "://";
  if ($_SERVER["SERVER_PORT"] != "80") {
    $pageURL .= $_SERVER["SERVER_NAME"].":".$_SERVER["SERVER_PORT"].$_SERVER["REQUEST_URI"];
  }
  else {
    $pageURL .= $_SERVER['SERVER_NAME'].$_SERVER['REQUEST_URI'];
  }
 return $pageURL;
}

function fgw_data_permitted( $row ) {
  global $livedefault;
  $allow_living = empty( $_SESSION['allow_living'] ) ? false : $_SESSION['allow_living'];
  $allow_private = empty( $_SESSION['allow_private'] ) ? false: $_SESSION['allow_private'];
  $assignedbranch = empty( $_SESSION['assignedbranch'] ) ? false : $_SESSION['assignedbranch'];
  $assignedtree = empty( $_SESSION['assignedtree'] ) ? false : $_SESSION['assignedtree'];
  while( true ) {
    $permitted = false;
    if( !empty( $row['living'] ) || !empty( $row['private'] ) ) {
      if( $row['living'] ) {
        if( $livedefault == LIV_NEVER) {
          break;
        }
        elseif( !$allow_living && $livedefault != LIV_ALWAYS ) {
          break;
        }
      }
      if( $row['private'] && !$allow_private) {
        break;
      }
      if( $assignedtree && $assignedtree != '-x-guest-x-' ) {
        if( $assignedtree != $row['gedcom'] ) {
          break;
        }
        if( $assignedbranch ) {
          if( FALSE === strpos( $row['branch'], $assignedbranch, 0 ) ) {
              break;
          }
        }
      }
    }
    $permitted = true;
    break;
  }
  return $permitted;
}

function fgw_delete_worksheet( $formID ) {
    global $options;
    $query = "DELETE FROM {$options['table']} WHERE formID='$formID'";
    db_delete( $query);
}

function fgw_sanitize_recursive( $variable ) {
  if ( is_string( $variable ) ) {
    $variable = trim($variable);
    $variable = htmlspecialchars($variable);
    return stripslashes( $variable );
  }
  if ( is_array( $variable ) ) {
    foreach( $variable as $i => $value ) {
      $variable[ $i ] = fgw_sanitize_recursive( $value );
    }
  }
  return $variable ;
}

/*************************************************************************
ALL TABLES
*************************************************************************/

function fgw_fetch_column_names( $table ) {
	$names = array();
  $rows = db_select( "DESCRIBE $table" );
  if( !count( $rows ) ) {
    trigger_error( 'Unable to get column names', E_USER_WARNING );
  }
  foreach( $rows as $row ) {
			$names[] = $row['Field'];
	}
  return $names;
}

function fgw_fetch_empty_record( $gedcom, $table ) {
  $rec = array();
  $names = fgw_fetch_column_names( $table );
  foreach( $names as $name ) {
    $rec[$name] = '';
  }
  if( isset( $rec['gedcom'] ) ) {
     $rec['gedcom'] = $gedcom;
  }
  return $rec;
}

function fgw_format_id( $prefix, $id ) {
	$id = trim( $id );
	$id = is_numeric( $id ) ? $prefix . $id : $id;
	if( !is_numeric( substr( $id, 1 ) ) ) return '';
	return ucfirst( $id );
}

/*************************************************************************
CHILDREN
*************************************************************************/

function fgw_fetch_children( $gedcom, $familyID ) {
  global $children_table, $people_table;
  $retrows = array();
  $private_row = fgw_fetch_empty_record( $gedcom, $people_table );
  $private_row['firstname'] = 'Private';
  $query = "SELECT pt.* FROM $children_table ct
    LEFT JOIN $people_table pt USING(gedcom, personID)
    WHERE gedcom='$gedcom'
    AND familyID='$familyID'
    ORDER BY ordernum";
  $rows = db_select( $query );
  foreach( $rows as $row ) {
    if( !fgw_data_permitted( $row ) ) {
      $retrows[] = $private_row;
    }
    else {
      $retrows[] = $row;
    }
  }
  return $retrows;
}

function fgw_fetch_child_record( $gedcom, $familyID, $personID ) {
   global $children_table;

   $query = "SELECT * FROM $children_table
      WHERE gedcom='$gedcom'
      AND familyID='$familyID'
      AND personID='$personID'";
   $rows = db_select( $query );
   return $rows[0];
}

/*************************************************************************
FAMILIES
*************************************************************************/

function fgw_fetch_family_record( $gedcom, $familyID ) {
   global $families_table;
   $family = fgw_fetch_empty_record( $gedcom, $families_table );
   if( !empty( $gedcom ) && !empty( $familyID ) ) {
      $query = "SELECT * FROM $families_table
         WHERE gedcom='$gedcom'
         AND familyID='$familyID'";
      $rows = db_select( $query );
      if( count( $rows ) ) {
         $family = $rows[0];
      }
   }
   else
      $family['gedcom'] = $gedcom;
   return $family;
}

function fgw_fetch_spouselist( $gedcom, $personID ) {
   global $families_table, $person_table;

   // find all records for spouseID
   // get spouse id
   // get spouse name
   // create recs spouselist[id]=name;
   $splist = array();
   $query = "SELECT familyID, husband, wife FROM $families_table
      WHERE gedcom='$gedcom'
      AND (husband='$personID' OR wife='$personID')";
   $rows = db_select( $query );
   foreach( $rows as $row ) {
      $sprec = '';
      $spname = '';
      if( $row['husband'] != $personID ) {
         $sprec = fgw_fetch_person( $gedcom, $row['husband'] );
         $spname = fgw_format_name( $sprec );
         $splist[$row['familyID']] = $spname;
      }
      else {
         $sprec = fgw_fetch_person( $gedcom, $row['wife'] );
         $spname = fgw_format_name( $sprec );
         $splist[$row['familyID']] = $spname;
      }
   }
   return $splist;
}

/*************************************************************************
PEOPLE
*************************************************************************/

function fgw_fetch_person( $gedcom, $personID ) {
  global $people_table;
  $person = fgw_fetch_person_empty( $gedcom );
  if( !empty( $gedcom ) && !empty( $personID ) ) {
    $query = "SELECT * FROM $people_table
      WHERE gedcom='$gedcom'
      AND personID='$personID'";
    $rows = db_select( $query );
    if( count( $rows ) ) {
      if( fgw_data_permitted( $rows[0] ) ) {
        $person = $rows[0];
      }
      else {
        $person['firstname'] = '* private *';
      }
    }
  }
  return $person;
}

function fgw_fetch_person_empty( $gedcom ) {
   global $people_table;
   $row = fgw_fetch_empty_record( $gedcom, $people_table );
   $row['gedcom'] = $gedcom;
   return $row;
}

function fgw_fetch_sex( $gedcom, $personID ) {
  global $people_table;
  $query = "SELECT sex FROM $people_table
    WHERE gedcom='$gedcom'
    AND personID='$personID'";
  $rows = db_select( $query );
  if( count( $rows ) )
    $sex = $rows[0]['sex'];
  else
    $sex = '';
  return $sex;
}

function fgw_format_namestr( $first, $last ) {
	$first = trim( $first );
	$last = trim( $last );
    if (empty( $first ) && empty( $last ) ) return "";
	if( !empty( $first ) )
		$outstring = "$first ";
	else
		$outstring = "? ";

	if( !empty( $last ) )
		$outstring .= $last;
	else
		$outstring .= "?";
	return $outstring;
}

//get husb or wife vitals/parents/spouses from tng database
function fgw_fetch_spouse_datapack( $gedcom, $personID ) {
  $spouse = fgw_fetch_person( $gedcom, $personID );

  if( !empty( $spouse['famc'] ) ) {

      // add "sealed to parents" data for LDS
      $row = fgw_fetch_child_record( $gedcom, $spouse['famc'], $personID );
      //$spouse['sealdate'] = $row['sealdate'];
      //$spouse['sealplace'] = $row['sealplace'];
      $spouse['parsfam']['familyID'] = $row['familyID'];
      $spouse['parsfam']['sealdate'] = $row['sealdate'];
      $spouse['parsfam']['sealplace'] = $row['sealplace'];


      $family = fgw_fetch_family_record( $gedcom, $spouse['parsfam']['familyID'] );
      $spouse['father'] = fgw_fetch_person( $gedcom, $family['husband'] );
      //$spouse['father']['familyID'] = $spouse['familyID'];
      $spouse['mother'] = fgw_fetch_person( $gedcom, $family['wife'] );
      //$spouse['mother']['familyID'] = $spouse['familyID'];
   }
   else {
      //$spouse['sealdate'] = '';
      //$spouse['sealplace'] = '';
      $spouse['father'] = fgw_fetch_person_empty( $gedcom );
      //$spouse['father']['familyID'] = '';
      $spouse['mother'] = fgw_fetch_person_empty( $gedcom );
      //$spouse['mother']['familyID'] = '';
      $spouse['parsfam']['familyID'] = '';
      $spouse['parsfam']['sealdate'] = '';
      $spouse['parsfam']['sealplace'] = '';
   }
   $spouse['splist'] = fgw_fetch_spouselist( $gedcom, $personID );
   return $spouse;
}

function fgw_fetch_spouse_datapack_empty( $gedcom, $husbwife=null ) {
   $spouse = fgw_fetch_person_empty( $gedcom );
   $spouse['sexM'] = $husbwife == 'husb' ? "selected=\"selected\"" : null;
   $spouse['sexF'] = $husbwife == 'wife' ? "selected=\"selected\"" : null;
   $spouse['sexU'] = null;
   $spouse['livchecked'] = "checked";

   $spouse['parsfam']['familyID'] = '';
   $spouse['parsfam']['sealdate'] = '';
   $spouse['parsfam']['sealplace'] = '';

   //$spouse['sealdate'] = $spouse['sealplace'] = '';
   $spouse['father'] = $spouse['mother'] = fgw_fetch_person_empty( $gedcom );
   return $spouse;
}

/*************************************************************************
TREES
*************************************************************************/

function fgw_fetch_first_gedcom() {
  global $trees_table, $treelist;
  if( !empty( $treelist ) ) {
    $trees = explode(',', $treelist );
      return trim( $trees[0] );
  }
  $trees = db_select( "SELECT gedcom FROM $trees_table LIMIT 1" );
  return $trees[0]['gedcom'];
}

function fgw_fetch_trees() {
  global $trees_table;
  $query = "SELECT * FROM $trees_table";
  return db_select( $query );
}

function fgw_fetch_permitted_trees( $treelist ) {
    global $assignedtree;

    // all trees on site
    $treerows = fgw_fetch_trees();

    // restrict to one tree if user is assigned to one
    if( !empty( $assignedtree ) && $assignedtree != '-x-guest-x-' ) {
        $row = fgw_get_tree_row( $assignedtree, $treerows );
        if( $row != false ) {
            $trees[] = $row;
        }
        else {
            // assume the tree exists if assigned by the admin
            // so flow should never come here
        }
    }
    // restrict to those listed in options treelist
    elseif( !empty( $treelist ) ) {
        $geds = explode( ',', $treelist );
        foreach( $geds as $ged ) {
            $row = fgw_get_tree_row( $ged, $treerows );
            if( $row != false ) {
                $trees[] = $row;
            }
        }
    }
    // return all trees without restriction
    else {
        $trees = $treerows;
    }
    return $trees;
}

function fgw_get_tree_row( $gedcom, $treerows ) {
    foreach( $treerows as $row ) {
        if( $row['gedcom'] == $gedcom ) {
            return $row;
        }
    }
    return false;
}

function fgw_in_trees( $gedcom, $treerows ) {
    foreach( $treerows as $row ) {
        if( strtolower( $row['gedcom'] ) == strtolower( $gedcom ) ) return true;
    }
	return false;
}

function fgw_fetch_treename( $gedcom ) {
   global $trees_table;
   $query = "SELECT treename FROM $trees_table
      WHERE gedcom='$gedcom'";
   $rows = db_select( $query );
   return $rows[0]['treename'];
}

function fgw_tree_selector( $trees, $gedcom, $disabled=false ) {
global $text;

   if( count( $trees ) == '1' ) {
      $state = "disabled=\"disabled\"";
      $disabled = true;
   }
   else
      $state = $disabled ? "disabled=\"disabled\"" : null;

   $display = '';
   //$display = count( $trees ) > 1 ? null : "style=\"display:none\";\"";

	$num_trees = count( $trees );
    $textlabel = $disabled
        ? "<span class=\"formlabel\">{$text['ws_familytree']}</span> "
        : "<span class=\"formlabel\">{$text['ws_select_tree']}</span> ";
    $treestring = "<div id=\"treemenu\" $display>
$textlabel:
<select id=\"gedcom\" name=\"gedcom\" $state>
";
  foreach ($trees as $tree) {
  $sel_tree = $gedcom == $tree['gedcom'] ? "selected=\"selected\"" : NULL;
  $treestring .= "<option value=\"{$tree['gedcom']}\" $sel_tree>{$tree['treename']}</option>
";
  }
  $treestring .= "</select>
</div>";
   if( $disabled ) {
      $treestring .= "
<input type=\"hidden\" name=\"gedcom\" value=\"$gedcom\" />";
   }
   return $treestring;
}

/*************************************************************************
USER
*************************************************************************/

function fgw_fetch_user( $currentuser='' ) {
  global $users_table;
  if( !empty( $currentuser ) ) {
    $query = "SELECT * FROM $users_table
      WHERE username='$currentuser'";
    $rows = db_select( $query );
    return $rows[0];
  }
  else
    return fgw_fetch_empty_record( $gedcom, $users_table );
}

function fgw_fetch_user_datapack( $currentuser='' ) {
  $row = fgw_fetch_user( $currentuser );
  if( $row['userID'] ) {
    $credits = $row['realname'];
    $credits .= empty( $row['city'] ) ? '' : ', '.$row['city'];
    $credits .= empty( $row['state'] ) ? '' : ', '.$row['state'];
    $credits .= empty( $row['country'] ) ? '' : ', '.$row['country'];
  }
  else {
      $credits = '';
  }

  $u = array(
    'realname' => $row['realname'],
    'city' => $row['city'],
    'state' => $row['state'],
    'country' => $row['country'],
    'email' => $row['email'],
    'credit' => $credits
  );
  return $u;
}

function fgw_fetch_user_datapack_empty() {
    $u = array(
        'realname' => '',
        'city' => '',
        'state' => '',
        'country' => '',
        'email' => '',
        'credit' => ''
      );
    return $u;
}

/*************************************************************************
MISC DATAPACKS
*************************************************************************/

function fgw_fetch_persfam_data( $gedcom, $persfamID ) {
  global $text, $families_table;

  $persfamID = trim( strtoupper( $persfamID ) );
  if( $persfamID[0] == 'F' ) {

    $f['marr'] = fgw_fetch_family_record( $gedcom, $persfamID );
    if( !fgw_data_permitted( $f['marr'] ) ) {
      $f['marr'] = fgw_fetch_empty_record( $gedcom, $families_table );
      $f['husb'] = fgw_fetch_spouse_datapack_empty( $gedcom, 'husb' );
      $f['wife'] = fgw_fetch_spouse_datapack_empty( $gedcom, 'wife' );
    }
    else {
      // get each spouse and fill
      $f['husb'] = fgw_fetch_spouse_datapack( $gedcom, $f['marr']['husband'] );
      $f['wife'] = fgw_fetch_spouse_datapack( $gedcom, $f['marr']['wife'] );
      $f['child'] = fgw_fetch_children( $gedcom, $persfamID );
    }
  }
  elseif( $persfamID[0] == 'I' ) {
    $person = fgw_fetch_person( $gedcom, $persfamID );
    $role = fgw_fetch_sex( $gedcom, $persfamID ) == 'M' ? 'husb' : 'wife';
    $spouserole = $role == 'husb' ? 'wife' : 'husb';
    $f['marr'] = fgw_fetch_empty_record( $gedcom, $families_table );
    $f[$role] = fgw_fetch_spouse_datapack( $gedcom, $persfamID );
    $f[$spouserole] = fgw_fetch_spouse_datapack_empty( $gedcom, $spouserole );
  }
  return $f;
}

function fgw_fetch_persfam_data_empty( $gedcom ) {
  global $families_table;
  $f['marr'] = fgw_fetch_empty_record( $gedcom, $families_table );
  $f['husb'] = fgw_fetch_spouse_datapack_empty( $gedcom, 'husb' );
  $f['wife'] = fgw_fetch_spouse_datapack_empty( $gedcom, 'wife' );
  return $f;
}

/************************************************************************
FORM COMPONENTS
************************************************************************/

function fgw_title( $husb, $wife ) {
   $husbName = fgw_format_name( $husb );
   $wifeName = fgw_format_name( $wife );
   $formTitle = '';
   if( empty( $husbName) & empty( $wifeName ) )
      return '';
   if( !empty( $husbName ) && !empty( $wifeName ) ) {
    $formTitle .= "$husbName & $wifeName";
   }
   elseif( !empty( $husbName ) ) {
    $formTitle .= $husbName;
   }
   elseif( !empty( $wifeName ) ) {
    $formTitle .= $wifeName;
   }
   return $formTitle;
}

function fgw_fetch_form_record( $formID, $fkey='') {
    global $options;
    $query = "SELECT * from {$options['table']}
        WHERE formID='$formID'";
    if( !empty( $fkey ) ) {
        $query .= " AND fkey='$fkey'";
    }
    $rows = db_select( $query );
    if( count( $rows ) ) {
        return $rows[0];
    }
    else
        return false;
}

function fgw_format_name( $nameset, $full=false ) {
    global $text;
    if( empty( $nameset['firstname'] ) && empty( $nameset['lastname'] ) )
        return null;
	$firstname = !empty( $nameset['firstname'] ) ? trim( $nameset['firstname'] ) : NULL;
	$lastname = !empty( $nameset['lastname'] ) ? trim( $nameset['lastname'] ) : NULL;
	if( $full ) {
  	$nickname = !empty( $nameset['nickname'] ) ? trim( $nameset['nickname'] ) : NULL;
  	$title = !empty( $nameset['title'] ) ? trim( $nameset['title'] ) : NULL;
  	$prefix = !empty( $nameset['prefix'] ) ? trim( $nameset['prefix'] ) : NULL;
  	$suffix = !empty( $nameset['suffix'] ) ? trim( $nameset['suffix'] ) : NULL;
	}
	$namestr = "";
	$namestr .= empty( $title ) ? '' : trim( $title ) . " ";
	$namestr .= empty( $firstname ) ? $text['ws_unknown'].' ' : trim( $firstname ) . " ";
	$namestr .= empty( $nickname ) ? '' : "(" . trim( $nickname ) . ") ";
	$namestr .= empty( $prefix ) ? '' : trim( $prefix ) . " ";
	$namestr .= empty( $lastname ) ? $text['ws_unknown'] : trim( $lastname );
	$namestr .= empty( $suffix ) ? '' : ", " . trim( $suffix );
	return $namestr;
}

function fgw_nav2( $args ) {
    global $options, $assignedtree;

    $direction = empty( $args['prev']  ) ? "ASC" : "DESC";
    $where = 'WHERE ';
    $where .= $direction == 'DESC'
        ? "formID<'{$args['formID']}'"
        : "formID>'{$args['formID']}'";

   // no filter - show any form
   if( !empty( $args['filter'] ) ) {
      if( $args['filter'] == 'pending' ) {
         $where .= " AND (merged=0 AND closed=0)";
         $_SESSION['filter'] = 'pending';
      }
      elseif( $args['filter'] == 'merged' ) {
         $where .= " AND merged=1";
         $_SESSION['filter'] = 'merged';
      }
      elseif( $args['filter'] == 'closed' ) {
         $where .= " AND closed=1";
         $_SESSION['filter'] = 'closed';
      }
      else
      unset( $_SESSION['filter'] );
   }

    if( $assignedtree) {
    $treelimit = "(gedcom='$assignedtree' OR gedcom='')";
    }
    else {
        $treelimit = '';
    }
    if( !empty( $treelimit ) ) {
        $where .= " AND $treelimit";
    }
    $query = "SELECT formID from {$options['table']}
        $where
        ORDER BY formID $direction
        LIMIT 1";
    //echo __FILE__,' ',__LINE__,' ',$query;exit;

    $rows = db_select( $query );
    //echo __LINE__,' ';print_r($rows);exit;
    if( count( $rows ) )
      return $rows[0]['formID'];
   else {
      $where = 'WHERE 1';
      if( !empty( $treelimit ) )
         $where .= " AND $treelimit";
      if( $args['filter'] == 'pending' )
         $where .= ' AND merged=0 AND closed=0';
      elseif( $args['filter'] == 'merged' )
         $where .= ' AND merged=1';
      elseif( $args['filter'] == 'closed' )
         $where .=  ' AND closed=1';

      $query = "SELECT formID from {$options['table']}
         $where
         ORDER BY formID $direction
         LIMIT 1";
      //echo $query;exit;
      $rows = db_select( $query );
      if( count( $rows ) )
         return $rows[0]['formID'];
      else
         return $args['formID'];
   }
}

function fgw_show_spouse( $role, $spdata, $familyID='' ) {
   global $text, $allow_lds, $options, $disabled;

   // data is entered by user with no import from database - prevent warnings
   if( !isset( $spdata['famc'] ) ) $spdata['famc'] = '';

    // family table column name for this spouse
    $fcol = $role == 'husb' ? 'husband' : 'wife';

    // for empty dataset sex defaults to M for husband and F for wife
    if( empty( $spdata['sex'] ) )
        $spdata['sex'] = $role == 'husb' ? 'M' : 'F';

    // which sex will be selected by default in the drop down list?
    $sexM = $spdata['sex'] == 'M' ? "selected=\"selected\"" : null;
    $sexF = $spdata['sex'] == 'F' ? "selected=\"selected\"" : null;
    $sexU = $spdata['sex'] == 'U' ? "selected=\"selected\"" : null;

    // set spouse title index and button names based on form position
    if( $role == 'husb' ) {
        $insert = 'hinsert';
        $remove = 'hremove';
        $tidx = 'ws_title_husband';
    }
   else {
      $insert = 'winsert';
      $remove = 'wremove';
      $tidx = 'ws_title_wife';
   }

      // set appropriate living flags
      $splive = !empty( $spdata['living'] ) ? "checked=\"checked\"" : "";
      $fatherlive = !empty( $spdata['father']['living'] ) ? "checked=\"checked\"" : "";
    $motherlive = !empty( $spdata['mother']['living'] ) ? "checked=\"checked\"" : "";

   // select role in family (husband, wife or partner)
   $out = "
<div class=\"pagerow\">&nbsp;</div>
<div class=\"pagerow\">
   <div class=\"pagecell\">
      <select name=\"{$role}[role]\" >
         <option>{$text[$tidx]}</option>
         <option>{$text['ws_title_partner']}</option>
      </select>
   </div>

   <div class='pagecell'>
      <span class=\"formlabel\">{$text['ws_personid']}: </span>
	</div>";

   if( !$disabled ) {
      // select person by ID
      $out .= "
	<div class='pagecell'>
		<input id=\"{$role}ID\" class=\"idfield topleft\" style='top:0;left:0;' type=\"text\" name=\"{$role}[personID]\" value=\"{$spdata['personID']}\" />
		<input name=\"{$role}[famc]\" value=\"{$spdata['famc']}\" type=\"hidden\" />
	</div>
	<div class='pagecell'>
		<span id=\"$insert\" class=\"icondiv\" title=\"{$text['ws_insertinfo']}\">
			<img src=\"img/plus.png\" alt=\"\" />
		</span>

		<span id=\"$remove\" class=\"icondiv\" title=\"{$text['ws_clearinfo']}\">
			<img src=\"img/minus.png\" alt=\"\" />
		</span>

		<span class=\"icondiv\">
			<img src=\"img/help.png\" alt=\"\" title=\"{$text['ws_qm_info']}\"
				onclick =\"return show_help('{$text['ws_personid_help']}');\" />
		</span>
	</div>";

   }
    else {
      // disable personID field
      $out .= "
	<div class='pagecell'>
      <input class=\"idfield\" style='top:0;left:0;' type=\"text\" value=\"{$spdata['personID']}\"
         disabled=\"disabled\" />
      <input name=\"{$role}[personID]\" value=\"{$spdata['personID']}\"
         type=\"hidden\" />
	</div>";
   }

   $out .= "
	<div class='pagecell'>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</div>
   <div class='pagecell'>
      {$text['ws_sex']}:&nbsp;
      <select name=\"{$role}[sex]\" onchange=\"return sexlabel( 'label{$role}', this.value);\">
         <option value=\"M\" $sexM>{$text['ws_male']}</option>
         <option value=\"F\" $sexF>{$text['ws_female']}</option>
         <option value=\"U\" $sexU>{$text['ws_sexunk']}</option>
      </select>
   </div>";

      // select spouse for inidividual from list
      $out .= "
   <div class=\"pagecell nowrap formlabel\">
      {$text['ws_marriages']}:&nbsp;
      <select id=\"{$role}marrs\" class=\"marrs\" style=\"width:160px;\" name=\"{$role}[spouse]\" onchange=\"return getFamily(this.value);\">
         <option value=\"{$spdata['personID']}\"></option>";
   if( !empty( $spdata['splist'] ) ) {
      foreach( $spdata['splist'] as $key => $value ) {
         $selected = $key == $familyID ? "selected" : '';
         $out .= "
            <option $selected value=\"$key\">$value</option>";
      }
   }
         $out .= "
      </select>
   </div>
</div>";

   $parents = "ws_".$role."_parents";
   $self = "ws_".$role;

/*************************************************************************
SELF IDENTITY
*************************************************************************/
   $out .= "
<div class=\"pagerow subheading\">
   {$text[$self]}
</div>

<div class=\"formrow\">

<!-- $fcol title -->
	<div class=\"ascell\" style=\"display:inline-block\">
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_title']}</div>
		<input type=\"text\" class=\"title\" name=\"{$role}[title]\" value=\"{$spdata['title']}\" />
	</div>

<!-- $fcol prefix -->
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_prefix']}</div>
		<input type=\"text\" class=\"prefix\" name=\"{$role}[prefix]\" value=\"{$spdata['prefix']}\" />
	</div>
	</div>
	
<!-- $fcol first name(s) -->
	<div class=\"ascell\" style=\"display:inline-block\">
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_firstnames']}</div>
		<input type=\"text\" id=\"{$role}first\" class=\"firstname\" name=\"{$role}[firstname]\" value=\"{$spdata['firstname']}\" />
	</div>

<!-- $fcol last name -->
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_lastname']}</div>
		<input type=\"text\" id=\"{$role}last\" class=\"lastname\" name=\"{$role}[lastname]\" value=\"{$spdata['lastname']}\" placeholder=\"{$text['ws_atbirth']}\" />
	</div>
	</div>
	
<!-- $fcol suffix -->
	<div class=\"ascell\" style=\"display:inline-block\">
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_suffix']}</div>
		<input type=\"text\" class=\"suffix\" name=\"{$role}[suffix]\" value=\"{$spdata['suffix']}\" />
	</div>

<!-- $fcol nickname -->
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_nickname']}</div>
		<input type=\"text\" class=\"nickname\" name=\"{$role}[nickname]\" value=\"{$spdata['nickname']}\" />
	</div>

<!-- $fcol living flag -->
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_living']}</div>
		<input type=\"hidden\" value=\"0\" name=\"{$role}[living]\" />
		<input type=\"checkbox\" class=\"living\" name=\"{$role}[living]\" value=\"1\" $splive />
	</div>
	</div>
</div><!--formrow-->";
/*************************************************************************
FATHER
*************************************************************************/
   $out .= "
<!-- $role father -->
<div class=\"formrow\">
	<div class=\"ascell\" style=\"display:inline-block\">
	<div class=\"formcell\">
		<div class=\"asinput parent\">{$text['ws_father']}</div>
	</div>
	
<!-- $fcol father title -->
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_title']}</div>
		<input type=\"text\" class=\"title\" name=\"{$role}[father][title]\" value=\"{$spdata['father']['title']}\" />
	</div>

<!-- $fcol father prefix -->
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_prefix']}</div>
		<input type=\"text\" class=\"prefix\" name=\"{$role}[father][prefix]\" value=\"{$spdata['father']['prefix']}\" />
	</div>
	</div>
	
<!-- $fcol father first name(s) -->
	<div class=\"ascell\" style=\"display:inline-block\">
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_firstnames']}</div>
		<input type=\"text\" class=\"firstname\" name=\"{$role}[father][firstname]\" value=\"{$spdata['father']['firstname']}\" />
	</div>

<!-- $fcol father last name -->
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_lastname']}</div>
		<input type=\"text\" class=\"lastname\" name=\"{$role}[father][lastname]\" value=\"{$spdata['father']['lastname']}\" placeholder=\"{$text['ws_atbirth']}\" />
	</div>
	</div>

<!-- $fcol father suffix -->
	<div class=\"ascell\" style=\"display:inline-block\">
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_suffix']}</div>
		<input type=\"text\" class=\"suffix\" name=\"{$role}[father][suffix]\" value=\"{$spdata['father']['suffix']}\" />
	</div>

<!-- $fcol father nickname -->
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_nickname']}</div>
		<input type=\"text\" class=\"nickname\" name=\"{$role}[father][nickname]\" value=\"{$spdata['father']['nickname']}\" />
	</div>

<!-- $fcol father living flag -->
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_living']}</div>
		<input type=\"hidden\" value=\"0\" name=\"{$role}[father][living]\" />
		<input type=\"checkbox\" class=\"living\" name=\"{$role}[father][living]\" value=\"1\" $fatherlive />
	</div>
	</div>
</div><!--formrow-->";
/*************************************************************************
MOTHER
*************************************************************************/
   $out .= "
<!-- $role mother -->
<div class=\"formrow\">
	<div class=\"ascell\" style=\"display:inline-block\">
	<div class=\"formcell\">
		<div class=\"asinput parent\">{$text['ws_mother']}</div>
	</div>

<!-- $fcol mother title -->
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_title']}</div>
		<input type=\"text\" class=\"title\" name=\"{$role}[mother][title]\" value=\"{$spdata['mother']['title']}\" />
	</div>

<!-- $fcol mother prefix -->
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_prefix']}</div>
		<input type=\"text\" class=\"prefix\" name=\"{$role}[mother][prefix]\" value=\"{$spdata['mother']['prefix']}\" />
	</div>
	</div>
	
<!-- $fcol mother first name(s) -->
	<div class=\"ascell\" style=\"display:inline-block\">
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_firstnames']}</div>
		<input type=\"text\" class=\"firstname\" name=\"{$role}[mother][firstname]\" value=\"{$spdata['mother']['firstname']}\" />
	</div>

<!-- $fcol mother last name -->
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_lastname']}</div>
		<input type=\"text\" class=\"lastname\" name=\"{$role}[mother][lastname]\" value=\"{$spdata['mother']['lastname']}\" placeholder=\"{$text['ws_atbirth']}\" />
	</div>
	</div>

<!-- $fcol mother suffix -->
	<div class=\"ascell\" style=\"display:inline-block\">
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_suffix']}</div>
		<input type=\"text\" class=\"suffix\" name=\"{$role}[mother][suffix]\" value=\"{$spdata['mother']['suffix']}\" />
	</div>

<!-- $fcol mother nickname -->
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_nickname']}</div>
		<input type=\"text\" class=\"nickname\" name=\"{$role}[mother][nickname]\" value=\"{$spdata['mother']['nickname']}\" />
	</div>

<!-- $fcol mother living flag -->
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_living']}</div>
		<input type=\"hidden\" value=\"0\" name=\"{$role}[mother][living]\" />
		<input type=\"checkbox\" class=\"living\" name=\"{$role}[mother][living]\" value=\"1\" $motherlive />
	</div>
	</div>
</div><!--formrow-->";

/*************************************************************************
SELF BIRTH AND CHRISTENING
*************************************************************************/
   $out .= "
<!-- $fcol birth and christenting -->
<div class=\"formrow\">

	<div class=\"ascell\" style=\"display:inline-block\">
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_dateborn']}</div>
		<input type=\"text\" class=\"datefield\" name=\"{$role}[birthdate]\" placeholder=\"{$text['ws_ph_date']}\" value=\"{$spdata['birthdate']}\" onblur=\"checkDate(this);\" />
	</div>

	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_placeborn']}</div>
		<input type=\"text\" class=\"placefield\" name=\"{$role}[birthplace]\" placeholder=\"{$text['ws_ph_place']}\" value=\"{$spdata['birthplace']}\" />
	</div>
	</div>

	
	<div class=\"ascell\" style=\"display:inline-block\">
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_datechris']}</div>
		<input type=\"text\" class=\"datefield\" name=\"{$role}[altbirthdate]\" placeholder=\"{$text['ws_ph_date']}\" value=\"{$spdata['altbirthdate']}\" onblur=\"checkDate(this);\" />
	</div>

	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_placechris']}</div>
		<input type=\"text\" class=\"placefield\" name=\"{$role}[altbirthplace]\" placeholder=\"{$text['ws_ph_place']}\" value=\"{$spdata['altbirthplace']}\" />
	</div><!--formcell-->
	</div><!--ascell:nowrap-->
</div>";
/*************************************************************************
SELF LDS
*************************************************************************/
    $ldsstyle = $allow_lds && empty( $options['hide_lds'] ) ? "display:block" : "display:none";
    $out .= "
<div style=\"$ldsstyle;\"><!--show/hide lds-->

<!-- $fcol LDS baptized and confirmed -->
<div class=\"formrow\">
	<div class=\"ascell\" style=\"display:inline-block\">
   <div class=\"formcell\">
      <div class=\"label\">{$text['ws_datebapt']}</div>
      <input type=\"text\" class=\"datefield\" name=\"{$role}[baptdate]\" placeholder=\"{$text['ws_ph_date']}\" value=\"{$spdata['baptdate']}\" onblur=\"checkDate(this);\" />
   </div>

   <div class=\"formcell\">
      <div class=\"label\">{$text['ws_lds_place']}</div>
      <input type=\"text\" class=\"placefield\" name=\"{$role}[baptplace]\" value=\"{$spdata['baptplace']}\" />
   </div>
	</div>

   <div class=\"ascell\" style=\"display:inline-block\">
	<div class=\"formcell\">
      <div class=\"label\">{$text['ws_confdate']}</div>
      <input type=\"text\" class=\"datefield\" name=\"{$role}[confdate]\" placeholder=\"{$text['ws_ph_date']}\" value=\"{$spdata['confdate']}\" onblur=\"checkDate(this);\" />
   </div>

   <div class=\"formcell\">
      <div class=\"label\">{$text['ws_lds_place']}</div>
      <input type=\"text\" class=\"placefield\" name=\"{$role}[confplace]\" value=\"{$spdata['confplace']}\" />
   </div>
	</div><!--ascell-->
</div><!--formrow-->

<!-- $fcol init and endowed -->
<div class=\"formrow\">
	<div class=\"ascell\" style=\"display:inline-block\">
   <div class=\"formcell\">
      <div class=\"label\">{$text['ws_initdate']}</div>
      <input type=\"text\" class=\"datefield\" name=\"{$role}[initdate]\" placeholder=\"{$text['ws_ph_date']}\" value=\"{$spdata['initdate']}\" onblur=\"checkDate(this);\" />
   </div>

   <div class=\"formcell\">
      <div class=\"label\">{$text['ws_lds_place']}</div>
      <input type=\"text\" class=\"placefield\" name=\"{$role}[initplace]\" value=\"{$spdata['initplace']}\" />
   </div>
	</div>

	<div class=\"ascell\" style=\"display:inline-block\">
   <div class=\"formcell\">
      <div class=\"label\">{$text['ws_endldate']}</div>
      <input type=\"text\" class=\"datefield\" name=\"{$role}[endldate]\" placeholder=\"{$text['ws_ph_date']}\" value=\"{$spdata['endldate']}\" onblur=\"checkDate(this);\" />
   </div>

   <div class=\"formcell\">
      <div class=\"label\">{$text['ws_lds_place']}</div>
      <input type=\"text\" class=\"placefield\" name=\"{$role}[endlplace]\" value=\"{$spdata['endlplace']}\" />
   </div>
	</div>
</div><!--formrow-->

<!-- $fcol sealed -->
<div class=\"formrow\">
	<div class=\"ascell\" style=\"display:inline-block\">
   <div class=\"formcell\">
      <div class=\"label\">{$text['ws_sealdate']}</div>
      <input type=\"text\" class=\"datefield\" name=\"{$role}[parsfam][sealdate]\" placeholder=\"{$text['ws_ph_date']}\" value=\"{$spdata['parsfam']['sealdate']}\" onblur=\"checkDate(this);\" />
   </div>

   <div class=\"formcell\">
      <div class=\"label\">{$text['ws_lds_place']}</div>
      <input type=\"text\" class=\"placefield\" name=\"{$role}[parsfam][sealplace]\" value=\"{$spdata['parsfam']['sealplace']}\" />
   </div>
	</div>
</div><!--formrow-->
</div><!--show/hide LDS-->";
/*************************************************************************
SELF DEATH AND BURIAL
*************************************************************************/
   $out .= "
<!-- $fcol death and burial -->
<div class=\"formrow\">
	<div class=\"ascell\" style=\"display:inline-block\">
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_datedied']}</div>
		<input type=\"text\" class=\"datefield\" name=\"{$role}[deathdate]\" placeholder=\"{$text['ws_ph_date']}\" value=\"{$spdata['deathdate']}\" onblur=\"checkDate(this);\" />
	</div>

	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_placedied']}</div>
		<input type=\"text\" class=\"placefield\" name=\"{$role}[deathplace]\" placeholder=\"{$text['ws_ph_place']}\" value=\"{$spdata['deathplace']}\" />
	</div>
	</div>

	<div class=\"ascell\" style=\"display:inline-block\">
	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_burialdate']}</div>
		<input type=\"text\" class=\"datefield\" name=\"{$role}[burialdate]\" placeholder=\"{$text['ws_ph_date']}\" value=\"{$spdata['burialdate']}\" onblur=\"checkDate(this);\" />
	</div>

	<div class=\"formcell\">
		<div class=\"label\">{$text['ws_burialplace']}</div>
		<input type=\"text\" class=\"placefield\" name=\"{$role}[burialplace]\" placeholder=\"{$text['ws_ph_burplace']}\" value=\"{$spdata['burialplace']}\" />
	</div>
	</div>
</div><!--formrow-->
<div class=\"clear\"></div>";
    echo $out;
} //fgw_show_spouse

?>