<?php
/**
Name: fgw_worksheet.php
Written by: William F. BIsbee

Description: Full Family Group Worksheet Form allowing private or public
(selectable) users to upload their detailed family history for inclusion
in the website family tree.  If a personID is entered for either head of
family (husband or wife), the worksheet retrieves that person's info from
database for editing.  That person's spouse may be added from a drop down
list.  If script is called with a query string that contains
valid gedcom and persfamID, the worksheet will prepopulate its fields from
the database.

jquery library updated in TNGv12.0. Deprecated functions are replaced here,
but this version is not backward compatible with TNG versions prior to 12.0.

Removes restrictions on Admin who can now save blank worksheets
Adds link to saved worksheet in admin area of form (to include email)
**/
/***************************************************************
LOCATE AND INCLUDE TNG LIBRARY FILES
***************************************************************/
// LIMIT PUBLIC SCRIPT ACCESS TO AUTHORIZED USERS
while( true ) {
	include 'user_config.php';
	@session_start();
	if( !empty( $_GET['id'] ) && !empty( $_GET['fkey'] ) ) break; // CREDENTIALS
	if( empty( $options['restricted'] ) ) break; 	// NO RESTRICTIONS
	if( !empty( $_SESSION['logged_in'] ) ) break;  	// MUST BE LOGGED IN
	$_SESSION['fgw_alert'] = 3;
	header( 'Location:fgw_alert.php' );
	exit;
}
 // make sure these are declared to avoid warnings
$id = '';
$fkey = '';
$persfamID = '';
$max_loglines = 1000;
$gedcom = '';
$familyID = '';
$personID = '';
$husbID = '';
$wifeID = '';

include 'fgw_lib.php';
include 'fgw_header.php';
include 'fgw_logger.php';
include 'version.php';

if( $_GET && is_array( $_GET ) ) {
	foreach( $_GET as $key=>$value ) {
		if($key == 'lang' || $key == 'mylanguage') die("sorry!");
		if(is_string($value))
			${$key} = strip_tags($value);
	}
}
elseif( $_POST && is_array( $_POST ) ) {
	foreach( $_POST as $key=>$value ) {
		if($key == 'lang' || $key == 'mylanguage') die("sorry!");
		${$key} = $value;
	}
}

// fgw_superuser set in fgw.php
$is_superuser = !empty( $_SESSION['fgw_superuser'] ) ? 1 : 0;
$currentuser = !empty( $_SESSION['currentuser'] ) ? $_SESSION['currentuser'] : '';
$allow_lds = $_SESSION['allow_lds'];

if( empty( $options['table'] ) || !db_table_exists( $options['table'] ) ) {
	$_SESSION['fgw_alert'] = 6;
   header( 'Location:fgw_alert.php' );
   exit;
}
if( !db_column_exists( $options['table'], 'gedcom' ) ) {
	$_SESSION['fgw_alert'] = 7;
	header( 'Location:fgw_alert.php' );
	exit;
 }

if( !isset( $_SESSION['fgw_guest'] ) ) $_SESSION['fgw_guest'] = 0;

/**************************************************************
ADMIN UTILITY OPS: DELETE, PREV, NEXT
***************************************************************/
// from $_GET
if( !empty( $_GET['del'] ) ) {
    if( !empty( $_GET['formID'] ) ) {
        fgw_delete_worksheet( $_GET['formID'] );
		  $logstring = "fgw#$formID {$text['ws_deletedby']}";
		  fgw_writelog( $options['userlog'], $logstring, $options['max_loglines'] );
        header('Location: fgw_search.php');
        exit;
    }
}
// from $_POST
elseif( !empty( $prev) || !empty( $next ) ) {
	if( $newform = fgw_nav2( $_POST ) ) {
	}
	header("Location: ../fgw.php?id=$newform");
	exit;
}

// IF NO HELP FILE IN SUPPORTED LANGUAGE USE ENGLISH
if( !file_exists( $fgw_language.'/help.php' ) ) {
    $fgw_language = 'English';
    $fgw_language .= $_SESSION['session_charset'] == 'UTF-8' ? '-UTF8' : '';
}
$help_file = $fgw_language.'/help.php';

// TAILORED MESSAGE FOR ADMINS - added in v43
if( $_SESSION['tngrole'] == 'admin' ) {
	$text['ws_intro'] = $text['ws_admin_intro'];
}

// Default instruction text
$notify = "<span class='info'><i>{$text['ws_intro']}</i></span>";

// default asterisk for required fields
define( "STAR", "<span style='color:{$options['error_msg_color']}; font-size:180%;'><strong>*</strong></span>");


/***************************************************************
SET SOME GLOBAL VALUES
***************************************************************/

/*
 * get query string values
 * @id: form id number to retrieve from database
 * @fkey: unique key for user access to their own form
 * USAGE: http://localhost/t1200t/fgw/fgw.php?id=3&fkey=8f0f7c1b8333312b57a4e99c913a1659
 */

// Do we know if form deals with a Family or an Individual?
if( !empty( $persfamID ) ) {
   if( strtoupper( $persfamID[0] == 'F' ) ) {
      $familyID = $persfamID;
   }
   elseif( strtoupper( $persfamID[0] == 'I' ) ) {
      $personID = $persfamID;
   }
}
else {
   $persfamID = '';
}

if( !empty( $tree ) )
   $gedcom = $tree;

// array of permitted trees (gedcom)
$trees = fgw_fetch_permitted_trees( $options['treelist'] );

if( empty( $gedcom ) ) $gedcom = $trees[0]['gedcom'];

$data = array();
$disabled = false;

/***************************************************************
ASSEMBLE FORM DATA PER REQUEST
***************************************************************/
// REQUESTING DATABASED WORKSHEET FROM LINK OR LIST
if( $id ) {
	//print_r($_POST);print_r($_GET);
	//echo __LINE__,' ',$id;exit;
	while( true ) { // validate user privileges; break to display form

		unset( $_SESSION['fgw_newform']);

		$valid_id = $valid_fkey = $valid_tree = $closed = false;
		if( is_numeric( $id ) ) {
			$form = fgw_fetch_form_record( $id );
			//echo __LINE__,' ';print_r( $form );exit;
			if( !empty( $form['formID'] ) ) {
				if( empty( $form['gedcom'] ) ) {
					$_SESSION['fgw_alert'] = 8;
					header('Location:fgw_alert.php'); //no_gedcom
					exit;
				}
				$valid_id = true;
				$valid_fkey = $fkey == $form['fkey'];
				$valid_tree = fgw_in_trees( $form['gedcom'], $trees );
				$closed = $form['closed'];
			}
		}

		if( !$valid_id ) {
			if( $is_superuser ) {
				header('Location:fgw_search.php');
				exit;
			}
			else { // display public error
				$_SESSION['fgw_alert'] = 1;
				header('Location:fgw_alert.php'); //notfound
				exit;
			}
		}

		// superuser must have access privilege to the requested tree
		if( $is_superuser ) {
			if( !$valid_tree ) {
				$_SESSION['fgw_alert'] = 3;
				header('Location:fgw_alert.php'); //noauth
				exit;
			}
			else {
				break;
			}
		}
		
		// submitter must have valid key and form must be open
		if( $valid_fkey ) {
			if( !$closed ) {
				break;
			}
			else {
				$_SESSION['fgw_alert'] = 2;
				header('Location:fgw_alert.php'); //form closed
				exit;
			}
		}
		else {
			$_SESSION['fgw_alert'] = 4;
			header('Location:fgw_alert.php'); //badkey
			exit;
		}
		break;
	} // while (processing)

	/*
     * EXTRACT FORM DATA
     * Form data is stored in the data base as a coded 'blob'
     * which must be decoded and unserialized into discrete data items.
     */
	$data = unserialize( base64_decode($form['data'] ) );


	// OLDER DATA RECORDS WILL THROW WARNINGS WITHOUT THE FOLLOWING
	// These fields were not in the very early records for FGW (@ 2014)
	// Saving these records as admin will eliminate the warnings at the source
	if( !isset( $data['marr']['husband'] ) ) {
		$data['marr']['husband'] = '';
	}
	if( !isset( $data['marr']['wife'] ) ) {
		$data['marr']['wife'] = '';
	}

	if( !isset( $data['husb']['title'] ) ) {     //wrong -> parents
		$data['husb']['title'] = '';
	}

	if( !isset( $data['husb']['mother']['title'] ) ) {     //wrong -> parents
		$data['husb']['mother']['title'] = '';
	}

	if( !isset( $data['husb']['father']['title'] ) ) {  	// wrong -> parents
		$data['husb']['father']['title'] = '';
	}

	if( !isset( $data['husb']['parsfam']['sealdate'] ) ) {     //wrong -> parents
		$data['husb']['parsfam']['sealdate'] = '';
	}

	if( !isset( $data['husb']['parsfam']['sealplace'] ) ) {
		$data['husb']['parsfam']['sealplace'] = '';
	}

	if( !isset( $data['wife']['title'] ) ) {     //wrong -> parents
		$data['wife']['title'] = '';
	}

	if( !isset( $data['wife']['mother']['title'] ) ) {     //wrong -> parents
		$data['wife']['mother']['title'] = '';
	}

	if( !isset( $data['wife']['father']['title'] ) ) {  	// wrong -> parents
		$data['wife']['father']['title'] = '';
	}

	if( !isset( $data['wife']['parsfam']['sealdate'] ) ) {     //wrong -> parents
		$data['wife']['parsfam']['sealdate'] = '';
	}

		if( !isset( $data['wife']['parsfam']['sealplace'] ) ) {
		$data['wife']['parsfam']['sealplace'] = '';
	}
	//echo __LINE__,' ';print_r($data);exit;
    /*
     * RETRIEVE METADATA
     */
	foreach( $form as $key => $value ) {
		if( $key == 'data' ) continue;
		${$key} = $value;
	}

	// disable tree selection for invited guest
	if( !$is_superuser && empty( $currentuser ) ) {
		$disabled = true;
	}
}
else {
	$_SESSION['fgw_newform'] = 1;
}

// REQUESTING A CHILD-DERIVED FORM (NEW PERSON)
if( empty( $data ) && !empty( $sv ) && !empty( $_SESSION['fgw_spouse'] ) ) {
    $spouse = $_SESSION['fgw_spouse'];
    //print_r( $spouse );exit;
    $role = empty( $spouse['husb'] ) ? 'wife' : 'husb';
    if( empty( $spouse[$role]['personID'] ) ) {
       unset( $_SESSION['fgw_spouse'] );
       unset( $sv );
       //$gedcom = $spouse[$role]['gedcom'];
       $user = $spouse['user'];
       $data = fgw_fetch_persfam_data_empty( $gedcom );

       foreach( $spouse[$role] as $key => $val ) {
          // echo $key,'=>',$val,'<br />';
           $data[$role][$key] = $val;
       }
    }
    else {
      //$gedcom = $spouse['gedcom'];
      $persfamID = $spouse[$role]['personID'];
    }
}

// REQUESTING PRE-FILLED FORM
if( empty( $data ) && !empty( $gedcom ) && !empty( $persfamID ) ) {
    if( $is_superuser || $currentuser || !$options['restricted'] ) {
        $data = fgw_fetch_persfam_data( $gedcom, $persfamID );
        $user = fgw_fetch_user_datapack( $currentuser );
        if( !fgw_in_trees( $gedcom, $trees ) ) {
        		$_SESSION['fgw_alert'] = 3;
            header( 'Location:fgw_alert.php' );
            exit;
        }
    }
    else {
        header("Location: {$cms['tngpath']}login.php");
        exit;
    }
}

// MERGE DATA FROM PARENT FORM FOR NEW CHILD FORM
if( !empty( $data ) && !empty( $sv ) && !empty( $spouse ) ) {
   unset( $_SESSION['fgw_spouse'] );
   foreach( $spouse[$role] as $key => $value ) {
      $data[$role][$key] = $value;
   }
   unset( $spouse );
}

// REQUESTING FORM FOR A DIFFERENT TREE (with blank form)
if( !empty( $gedcom ) && empty( $persfamID ) ) {
    if( !fgw_in_trees( $gedcom, $trees ) ) {
    		$_SESSION['fgw_alert'] = 3;
			header( 'Location:fgw_alert.php' );
			exit;
    }
}

// REQUESTING A BLANK FORM -- NEED GEDCOM HERE
if( empty( $data ) )  {
	// ADMIN PERSONAL DATA NOT PRE-FILLED - added by v43


	if( $is_superuser || $currentuser || empty( $options['restricted'] ) ) {
		if( empty( $gedcom ) ) {
			$gedcom = $trees[0]['gedcom'];
		}
		$data = fgw_fetch_persfam_data_empty( $gedcom );

		if( $is_superuser ) {
			$user = fgw_fetch_user_datapack_empty();
		}
		elseif( !empty( $_SESSION['fgw_user'] ) ) {
			$user = $_SESSION['fgw_user'];
		}
		elseif( $currentuser ) {
				$user = fgw_fetch_user_datapack( $currentuser );
				$_SESSION['fgw_user'] = $user;
		}
		else { // not logged in - no site restrictions
			$user = fgw_fetch_user_datapack_empty();
		}
	}
	else {
		header("Location: {$cms['tngpath']}login.php");
		exit;
	}
}

$tree_selector = fgw_tree_selector( $trees, $gedcom, $disabled );

foreach( $data as $key => $value ) {
    ${$key} = $value;
}

// UPDATED TO ALLOW ADMIN CREATE/EDIT - added in v43
$formTitle = empty( $description ) ? fgw_title($husb, $wife) : $description;
//$formTitle = fgw_title( $husb, $wife );

$formTitle = htmlspecialchars_decode( $formTitle, ENT_QUOTES | ENT_HTML5 );

if( !empty($options['show_captcha'] ) ) {
   $_SESSION['captcha_code'] = strtolower( substr( fgw_password(), 4) );
   $fgw_hash = md5( $_SESSION['captcha_code'] );
}

// if background image name is empty string,
// form will not set destinationpage8 value!
$form_bgimg = !empty( $form_bgimg ) ? $form_bgimg : "noimage";

// DEFAULT USER CONFIGURABLE WORKSHEET STYLES
$flags['scripting'] = "
	<!-- FGW DEFAULT STYLING -->
	<style type='text/css'>
		<!--
		.fgw_container {
			background-color:#fffff9;
		}
		.fgw_container input[type='text'],
		.fgw_container select,
		.fgw_container textarea,
		.fgw_container .formcell {
			background-color:white;
			font-weight:bold;
		}
		.fgw_container .formcell .label {
			color:#333;
			background-color:#ddd;
			border-bottom:1px solid #aaa;
		}
		.fgw_container .warning {color:red;}
		#husbdata { border-top:0px solid #aaa;}
		#wifedata { border-top:0px solid #aaa;}
		-->
	</style>";

/*** SET USER SELECTED STYLING ***/
# the following overrides default styles at runtime
# and prevents submitting the page with Return key
$opstyles = "
	<!-- USER SELECTED FGW STYLING OVERRIDES -->
	<style type='text/css'>
		<!--
		.fgw_container {";
	if( !empty( $options['form_background'] ) )
		$opstyles .= "
			background-color:{$options['form_background']};";

	if( !empty( $options['form_bgimg'] ) )
		$opstyles .= "
			background-image:url( {$options['form_bgimg']} );
			background-repeat:no-repeat;
			background-size:cover;";

	if( !empty( $options['form_border'] ) )
		$opstyles .= "
			border:{$options['form_border']};";

	if( !empty( $options['form_text_color'] ) )
		$opstyles .= "
			color:{$options['form_text_color']};";
$opstyles .= "
		}";
if( !empty( $options['form_text_color'] ) )
	$opstyles .= "
		.fgw_container a:link, a:visited, a:hover {
			color:{$options['form_text_color']};
		}";

if( !empty( $options['form_heading_color'] ) )
	$opstyles .= "
		.fgwheader {
			color:{$options['form_heading_color']};
		}";

if( !empty( $options['form_subhead_color'] ) )
	$opstyles .= "
		.fgw_container .subheading {
			color:{$options['form_subhead_color']};
		}";

$opstyles .= "
		.fgw_container input[type='text'],
		.fgw_container select,
		.fgw_container textarea,
		.fgw_container .formcell {";
if( !empty( $options['field_text_color'] ) )
	$opstyles .= "
			color:{$options['field_text_color']};";

if( !empty( $options['field_background_color'] ) )
$opstyles .= "
			background-color:{$options['field_background_color']};";

if( !empty( $options['form_text_bold']) )
	$opstyles .= "
			font-weight:bold;";

$opstyles .= "
		}";

if( !empty( $options['cell-border'] ) )
	$opstyles .= "
		.fgw_container .formcell {
   		border:{$options['cell_border']};
		}";

$opstyles .= "
		.fgw_container .formcell .label {";

if( !empty( $options['cellhead_color'] ) )
   $opstyles .= "
			color:{$options['cellhead_color']};";

if( !empty( $options['cellhead_bkgd'] ) )
	$opstyles .= "
			background-color:{$options['cellhead_bkgd']};";

if( !empty( $options['cell_border'] ) )
   $opstyles .= "
			border-bottom:{$options['cell_border']};";
$opstyles .= "
		}";

if( !empty( $options['form_labels'] ) )
	$opstyles .= "
		.fgw_container .formlabel {
   		color:{$options['form_labels']};
		}";

if( !empty( $options['error_msg_color'] ) )
	$opstyles .= "
		.fgw_container .warning {color:{$options['error_msg_color']};}";

if( !empty( $options['notify_msg_color'] ) )
	$opstyles .= "
		.fgw_container .success {color:{$options['notify_msg_color']};}";

if( !empty( $options['husb_bkgd' ] ) )
	$opstyles .= "
		#husbdata { background-color:{$options['husb_bkgd']};}";

if( !empty( $options['husb_img' ] ) )
	$opstyles .= "
		#husbdata { background-image:url({$options['husb_img']});}";

if( !empty( $options['form_border'] ) )
	$opstyles .= "
		#husbdata { border-top:{$options['form_border']};}";

if( !empty( $options['wife_bkgd' ] ) )
	$opstyles .= "
		#wifedata { background-color:{$options['wife_bkgd']};}";

if( !empty( $options['wife_img' ] ) )
	$opstyles .= "
		#wifedata { background-image:url({$options['wife_img']});}";

if( !empty( $options['form_border'] ) )
	$opstyles .= "
		#wifedata { border-top:{$options['form_border']};}";

$opstyles .= "
	-->
	</style>
	<script type='text/javascript'>
		var tnglitbox;
		var share = 0;
		var closeimg = '".$tngpath."img/tng_close.gif';
		var smallimage_url = '".$tngpath."ajx_smallimage.php?';
		var cmstngpath='".$tngpath."';
		var loadingmsg = 'Loading...';
		var expand_msg = 'Expand';
		var collapse_msg = 'Collapse';
	</script>
	<base target='_parent'>";

$preferEuro = $tngconfig['preferEuro'] ? $tngconfig['preferEuro'] : "false";

// USER STYLING + ADDITIONAL SCRIPTING
$flags['scripting'] .= "
$opstyles
	<script type='text/javascript'>
		<!--
		var newform = '{$text['ws_newform']}';
		var preferEuro = $preferEuro;
		var preferDateFormat = '';

		function stopRKey(evt) {
		  var evt = (evt) ? evt : ((event) ? event : null);
		  var node = (evt.target) ? evt.target : ((evt.srcElement) ? evt.srcElement : null);
		  if ((evt.keyCode == 13) && (node.type=='text'))  {return false;}
		}
		document.onkeypress = stopRKey;
		//-->
	</script>
	<script type='text/javascript' src='../js/tngmenuhover2.js'></script>";

fgw_header( 'Worksheet', $flags );

/***************************************************************
START WITH THE FORM TITLE
***************************************************************/
echo "
<!-- Form Title -->
<div class='fgw_container'>
   <div class='asrow'>
      <div class='ascell icondiv'>
         <img src='img/families.gif' width='24' height='24' alt='' />
      </div>
      <div class='ascell'>
         <span class='header fgwheader'>{$text['ws_fgw']}</span>
      </div>
   </div>";
/***************************************************************
SHOW ADMIN FORM
***************************************************************/
if( $is_superuser && $id ) {
   $merged_checked = empty( $form['merged'] ) ? null : "checked='checked'";
   $merged_style = $merged_checked ? null : 'background-color:yellow';
   $closed_checked = empty( $form['closed'] ) ? null : "checked='checked'";
   $closed_style = $closed_checked ? null : 'background-color:yellow';

   echo "\n
<!-- Admin Section -->
<div class='admin compact' style='border:1px dashed #555;padding:5px;'>
   <h2 class='pagerow' style='text-align:center;margin:0;'>{$text['ws_management']}<br />
<a style='font-size:65%;' href='fgw_showplain.php?id=$id&fkey=$fkey' target='_blank'>{$text['ws_linkplain']}</a></h2>

<!-- Admin Section Line 1 Current worksheet status -->
<div class='pagerow subheading'>
	{$text['ws_currentws']} ({$text['ws_update']} {$form['updated']})
</div>

	<form id='f_admin' action='' method=''>
		<div class='formrow'>

            <!-- Worksheet (ID) -->
			<div class='formcell'>
				<div class='label'>{$text['ws_worksheet']}</div>
				<div style='height:24px;line-height:24px;width:100%;text-align:center;'>
					$id
				</div>
			</div>

            <!-- Merged (worksheet status flag set by admin) -->
			<div class='formcell' style='$merged_style'>
				<div class='label'>{$text['ws_merged']}</div>
				<input type='checkbox' class='living' name='merged' value='1' $merged_checked />
			</div>

            <!-- Closed (worksheet status flag set by admin -->
			<div class='formcell' style='$closed_style'>
				<div class='label'>{$text['ws_closed']}</div>
				<input type='checkbox' class='living' name='closed' value='1' $closed_checked />
			</div>

            <!-- FamilyID (set by FGW or by admin) -->
			<div class='formcell'>
				<div class='label'>{$text['ws_familyid']}</div>
				<input type='text' name='familyID' value='{$form['familyID']}' size='8' />
			</div>

            <!-- HusbandID (set by FGW or by admin) -->
			<div class='formcell'>
				<div class='label'>{$text['ws_husbandid']}</div>
				<input type='text' name='husbID' value='{$form['husbID']}' size='8' />
			</div>


            <!-- WifeID (set by FGW or by admin) -->
			<div class='formcell'>
				<div class='label'>{$text['ws_wifeid']}</div>
				<input type='text' name='wifeID' value='{$form['wifeID']}' size='8' />
			</div>
		</div>
";

// ALLOW ADMIN TO ADD/EDIT WORKSHEET TITLE - added in v43
echo "
		<div class='formrow'>
			<div class='formcell'>
				<div class='label'>{$text['ws_wstitle']}</div>
				<input type='text' name='description' value=\"$formTitle\" size='59' />
			</div><!-- formcell -->
		</div><!-- formrow -->
";

echo "
        <!-- Current worksheet status controls -->
		<div class='asrow'>
			<div class='ascell'>
				<input type='hidden' name='formID' value='$id' />
				<input type='submit' name='update' value='{$text['ws_update']}' />
			</div>

			<div class='ascell'>
				<button type='button' onclick=\"if (confirm('{$text['ws_confdel']}')) {window.location.href='fgw_worksheet.php?formID=$id&del=1';}\">{$text['ws_delete']}</button>
			</div>
		</div>
	</form><!-- Admin Line 1 -->
   <div class='clear'></div>";

    echo "\n
    <!-- Admin Section Line 2 -->
	<div class='pagerow subheading'>
         {$text['ws_otherws']}
	</div>
    <div>
        <!-- Admin Line 2 Get different worksheet -->
        <form id='f_search' action='fgw_search.php' method='post' target='fgw'>
            <input type='submit' name='search'
        	value='{$text['ws_searchbyid']}'
        	title='familyID, husbandID, wifeID or worksheetID' />

            <input type='text' id='searchID' name='searchID' size='10' />
            <input type='hidden' name='backformID' value='$id' />
            <input type='hidden' name='backfkey' value='$fkey' />
            <input type='hidden' name='backtitle' value='{$form['description']}' />
        </form>
    </div>";

   $all = $pending = $merged = $closed = '';
   if( !empty( $_SESSION['filter'] ) ) {
      ${$_SESSION['filter']} = "checked='checked'";
   }
   else {
      $all = "checked='checked'";
   }

	$murl = $tngdomain."/fgw/fgw.php?id=$id&fkey=$fkey";

   echo "\n
    <!-- Admin Section Line 3 Navigation filter -->
	<form id='f_nav' action='fgw_worksheet.php' method='post'>
		<div class='astable'>
		    <div class='asrow'>
			    <div class='subheading'>{$text['ws_filter']}</div>
            </div>
		</div>
		
		<div class='astable'>
		    <div class='asrow'>

                <!-- Get next/previous worksheet -->
			    <div class='ascell'>
                    <label for='f1'>&nbsp;<span>{$text['ws_allforms']} </span>
                        <input type='radio' id='f1' class='' name='filter'
                            value='all' $all/>
                    </label>
						  &nbsp;&nbsp;&nbsp;&nbsp;
			    </div>

                <!-- Get next/previous Open worksheet -->
			    <div class='ascell'>
                    <label for='f2'><span>{$text['ws_pending']} </span>
                        <input type='radio' id='f2' class='' name='filter'
                            value='pending' $pending/>
                    </label>
						  &nbsp;&nbsp;&nbsp;&nbsp;
			    </div>

                <!-- Get next/previous Merged worksheet -->
			    <div class='ascell'>
                    <label for='f3'><span>{$text['ws_merged']} </span>
                        <input type='radio' id='f3' class='' name='filter'
                            value='merged' $merged/>
                    </label>
						  &nbsp;&nbsp;&nbsp;&nbsp;
			    </div>

                <!-- Get next/previous Closed worksheet -->
			    <div class='ascell'>
                    <label for='f4'><span>{$text['ws_closed']} </span>
                        <input type='radio' id='f4' class='' name='filter'
                            value='closed' $closed/>
                    </label>
			    </div>
		    </div>
			 <div class='asrow'><div class='ascell'>&nbsp;</div></div>
		</div>
		
        <!-- Navigation filter controls -->
		<div class='astable'>
		<div class='asrow'>
			<div class='ascell'>
            <input type='submit' name='prev' value='&laquo; {$text['ws_prev']}' />
            <input type='submit' name='next' value='{$text['ws_next']} &raquo;' />
				<input type='hidden' name='formID' value='$id' />
			</div>
		</div>

		<!-- Copyable link to this worksheet -->
		<div class='asrow'>
			<br />
			<div class='ascell' style='float:right'>
				<button type='button' onclick=\"copyToClipboard('link1')\">{$text['ws_copylink']}</button>
			 	&nbsp;&nbsp;<span id='link1' style='text-decoration:underline;'>$murl</span>
			</div>
		</div>
		</div>
	</form>";
	
   echo "\n
<div class='clear'></div>
</div><!-- Admin Section -->

<div class='clear'></div>
";
}

/***************************************************************
INSERT MAIN PART OF FORM -- FAMILY HISTORY
***************************************************************/
//$confirmation = 'e35325117ab18226b4ddf6c780a30acf';
echo "
<!-- FAMILY HISTORY -->
<form id='worksheet' name='worksheet' action='' method='' >
<div id='fgwfgw'>";

$confirmation = 'e35325117ab18226b4ddf6c780a30acf';

// INSERT MAIN FAMILY GROUP WORKSHEET FORM
include 'fgw_form.php';

echo "
</div><!-- FAMILY HISTORY -->";
/***************************************************************
NOTES TABLE
***************************************************************/
if( !isset( $unotes ) ) $unotes = '';
echo "
<div class='pagerow subheading'>
     {$text['ws_title_notes']}
</div>
<div class='pagerow'>
   <div>
      <textarea name='unotes' rows='4'>$unotes</textarea>
   </div>
</div>
";
/***************************************************************
SUBMITTER'S INFORMATION TABLE
***************************************************************/
if( !isset( $urelation ) ) $urelation = '';

echo "
<div id='usertab'><!--submitter information-->
<div class='pagerow subheading'>
     {$text['ws_submittedby']}
</div>

<div class='formrow'>
   <div class='formcell'>
      <div class='label'>{$text['ws_yourname']} <span class='{$options['error_msg_color']}'>({$text['ws_required']})</span></div>
      <input class='fullname' name='user[realname]' value='{$user['realname']}' type='text' />
   </div>

   <div class='formcell'>
      <div class='label'>{$text['ws_city']}</div>
      <input class='city' name='user[city]' value='{$user['city']}' type='text' />
   </div>

   <div class='formcell'>
      <div class='label'>{$text['ws_state']}</div>
      <input class='state' name='user[state]' value='{$user['state']}' type='text' />
   </div>

   <div class='formcell'>
      <div class='label'>{$text['ws_country']}</div>
      <input class='country' name='user[country]' value='{$user['country']}' type='text' />
   </div>

   <div class='formcell'>
      <div class='label'>{$text['ws_email']}  <span class='warning'>({$text['ws_required']})</span></div>
      <input class='email' name='user[email]' value='{$user['email']}' type='text' />
   </div>

   </div>
</div><!--#usertab-->

<div class='pagerow subheading'>
     {$text['ws_relationship']}
</div>
<div class='pagerow'>
      <textarea name='urelation' rows='4'>$urelation</textarea>
</div>

<div class='pagerow subheading'>
      {$text['ws_title_credits']}
</div>
<div class='pagerow'>
      <textarea name='user[credit]' rows='1'>{$user['credit']}</textarea>
</div>";

if( !empty( $options['show_captcha'] ) ) {
   echo "
<div class='pagerow'>&nbsp;</div>
<div class='asrow'>
	<div class='ascell' style='vertical-align:middle;'>
		{$text['ws_security']}
		<span class='{$options['error_msg_color']}'>({$text['ws_required']})</span>:
		
	</div>
	<div class='ascell' style='vertical-align:middle;'>
		<input type='text' id='capcode' name='capcode' size='5' value'' />
		<input type='hidden' id='fgw_hash' name='fgw_hash' value='$fgw_hash' />
	</div>
	<div class='ascell'>
		<img src='fgw_captcha.php' />
	</div>
</div>
";
}
/***************************************************************
FORM SUBMISSION CONTROLS TABLE
***************************************************************/
$mm_checked = empty( $sent )  || $mailme ? "checked='checked'" : "";
$href = 'fgw.php';		//$_SERVER['PHP_SELF'];
$href .= $_SESSION['fgw_guest'] ? '?vs=1' : "?tree=$gedcom";
// added in version 43
$tngrole = $_SESSION['tngrole'];
$admin = $tngrole == 'admin' ? "ADMIN: " : "";

echo "
<div class='pagerow compact'>
   <div style='text-align:center;'>
      &nbsp;
   </div>
</div>

<div class='pagerow compact'>
   <div class='pagecell'>
      <input type='submit' value='{$text['ws_savesubmit']}' id='submitted' name='submitted' />
      <input name='formID' value='$id' type='hidden' />
      <input type='hidden' name='persfamID' value='$persfamID' />
   </div>
</div>

<div class='pagerow compact'>
   <div style='text-align:center;'>
      <small><i>{$text['ws_form']} ver $version, rev $revdate</i></small>
   </div>
</div>

<div id='comments' >
  Do not enter anything into this field
	<input type='text' name='comment' value='' />
</div>
</form><!--worksheet-->

</div><!--fgw_container-->
<div style='display:none' id='wait'>
  <img src='img/ringspin.gif' alt='' />
</div>
";
/***************************************************************
	MESSAGE CACHES FOR JAVASCRIPT DISPLAYS
***************************************************************/
// message divs for javascript display
echo "
<div id='newtree' style='display:none'>{$text['ws_newtree']}</div>
<div id='nochanges' style='display:none'>{$text['ws_nochanges']}</div>
<div id='childline' style='display:none'>{$text['ws_childline']}</div>";
// added in version 43
echo "
<div id='userrole' style='display:none'>$tngrole</div>";
/***************************************************************
	FOOTER SCRIPTS
***************************************************************/
echo "
<script type='text/javascript' src='../js/datevalidation.js'></script>
<script type='text/javascript' src='../js/litbox.js'></script>
<script type='text/javascript' src='js/fgw_lib.js'></script>
<script type='text/javascript' src='js/jquery.dirty.js'></script>
<script type='text/javascript'>
// pure javascript
function copyToClipboard(elementId) {
  		// Create a 'hidden' input
  var aux = document.createElement('input');
  		// Assign it the value of the specified element
	aux.setAttribute('value', document.getElementById(elementId).innerHTML);
  		// Append it to the body
  document.body.appendChild(aux);
  		// Highlight its content
  aux.select();
  		// Copy the highlighted text
  document.execCommand('copy');
  		// Remove it from the body
  document.body.removeChild(aux);
}
</script>
</body>
</html>";
die();
