<?php
/*************************************************************************
Database interface using the MySQLi library
    * Copyright 2015 William Bisbee, all rights reserved
    * Dual licensed under the MIT and GPL licenses:
    *   http://www.opensource.org/licenses/mit-license.php
    *   http://www.gnu.org/licenses/gpl.html
*************************************************************************/
define( 'SELECT',   1 );
define( 'INSERT',   2 );
define( 'DELETE',   3 );
define( 'UPDATE',   4 );
define( 'REPLACE',  5 );
define( 'COUNT',    6 );
define( 'SYSTEM',   7 );
/*************************************************************************
OPEN THE DATABASE WITH GLOBAL HANDLE $DB
*************************************************************************/
// open mysqli
try {
  $DB = new mysqli( $database_host, $database_username,
                        $database_password );
  if( !$DB ) {
    throw new Exception( mysqli_connect_error() );
  }
}
catch( exception $e ) {
  echo 'Error: failed to connect to database!  Please try again or notify
        the administrator.';
  trigger_error( $e->getMessage(), E_USER_ERROR );
  exit;
}
// open the tng database
try {
  if( !$DB->select_db( $database_name ) ) {
    throw new Exception( 'Failed to open '.$database_name );
  }
}
catch( exception $e ) {
  echo 'Error: failed to connect to database!  Please try again or notify
        the administrator.';
  trigger_error( $e->getMessage(), E_USER_ERROR );
  exit;
}
// mysqli does not recognize TNG's 'UTF-8', only 'utf8' or 'latin1' (ISO-8859-1);
if( $charset == 'UTF-8' ) $charset = 'utf8';
if( $charset != 'utf8' ) $charset = 'latin1';
try {
  if( !$DB->set_charset( $charset ) ) {
    throw new Exception( 'Failed to set charset '.$charset.' for the database!' );
  }
}
catch( exception $e) {
  echo 'Error: failed to install the database character set!
  Please notify the system administrator.';
  trigger_error( $e->getMessage(), E_USER_ERROR );
  Exit;
}

/*************************************************************************
QUERIES
*************************************************************************/
// Library query handler
function db_query( $return_type, $query ){
global $DB;
   if( false === $result = $DB->query( $query ) ) {
      //print_r( debug_backtrace());
      trigger_error( $query.'<br />'.mysqli_error( $DB ), E_USER_ERROR);
      //throw new Exception( 'Query failed: '.$query );
   }
  // handle returns and cleanup
  switch( $return_type ){
    case COUNT:
      $row = $result->fetch_array();
      return( $row[0] );
      break;
    case SELECT:
      if( $result->num_rows ) {
        while( $row = $result->fetch_assoc() ) {
          $rows[] = $row;
        }
        $result->free();
        return $rows;
      }
      return array();
      break;

    case INSERT:
      if( $return_type == INSERT )
        return $DB->insert_id;
      break;

    case DELETE:
    case UPDATE:
    case REPLACE:
      return $DB->affected_rows;
      break;

    case SYSTEM:
        return $result;
        break;

    default:
      trigger_error( 'Unknown query type', E_USER_ERROR );
      break;
  }
}

function db_escape( $array ) {
global $DB;
if( !get_magic_quotes_gpc() )
	if( is_string( $array ) )  {
	  $array = $DB->real_escape_string( $array );
	}
	elseif( is_array ($array ) )  {
		foreach( $array as $key => $value )
			if( is_string( $value ) ) {
				$array[$key] = $DB->real_escape_string( $value );
			}
	}
	return $array;
}

function db_table_exists( $table_name ) {
    $rows = db_select( "SHOW TABLES LIKE '$table_name'" );
    return count( $rows );
}

function db_column_exists( $table_name, $column_name ) {
    $rows = db_select( "SHOW COLUMNS IN $table_name LIKE '$column_name'" );
    return count( $rows );
}

/*************************************************************************
COUNT
*************************************************************************/
function db_count( $query ) {
  return db_query( COUNT, $query );
}

/*************************************************************************
SELECT
*************************************************************************/
// ret: array of database rows();
function db_select( $query ) {
  return db_query( SELECT, $query );
}

/*************************************************************************
INSERT
*************************************************************************/
// ret new record ID
function db_insert( $query ) {
  return db_query( INSERT, $query );
}

/*************************************************************************
DELETE
*************************************************************************/
// ret: rows affected
function db_delete( $query ) {
  return db_query( DELETE, $query );
}

/*************************************************************************
REPLACE
*************************************************************************/
// ret: affected rows - two for each == one for deleted and one for added.
function db_replace($query ) {
  return db_query( REPLACE, $query );
}

/*************************************************************************
UPDATE
*************************************************************************/
// ret: number affected rows
function db_update( $query ) {
  return db_query( UPDATE, $query );
}
/*************************************************************************
SYSTEM
*************************************************************************/
// ret: number affected rows
function db_system( $query ) {
  return db_query( SYSTEM, $query );
}
?>